pub enum YearAmbiguity {
Unambiguous,
CenturyRequired,
EraRequired,
EraAndCenturyRequired,
}Expand description
Defines whether the era or century is required to interpret the year.
For example 2024 AD can be formatted as 2024, or even 24, but 1931 AD
should not be formatted as 31, and 2024 BC should not be formatted as 2024.
Variants
Unambiguous
The year is unambiguous without a century or era.
CenturyRequired
The century is required, the era may be included.
EraRequired
The era is required, the century may be included.
EraAndCenturyRequired
The century and era are required.