pub struct MonthCode(pub TinyAsciiStr<4>);Expand description
Representation of a month in a year
Month codes typically look like M01, M02, etc, but can handle leap months
(M03L) in lunar calendars. Solar calendars will have codes between M01 and M12
potentially with an M13 for epagomenal months. Check the docs for a particular calendar
for details on what its month codes are.
Month codes are shared with Temporal, see Temporal proposal.
Tuple Fields
0: TinyAsciiStr<4>Implementations
Sourceimpl MonthCode
impl MonthCode
Sourcepub fn get_normal_if_leap(self) -> Option<MonthCode>
👎Deprecated since 2.1.0
pub fn get_normal_if_leap(self) -> Option<MonthCode>
Sourcepub fn parsed(self) -> Option<(u8, bool)>
👎Deprecated since 2.1.0
pub fn parsed(self) -> Option<(u8, bool)>
Get the month number and whether or not it is leap from the month code
Sourcepub fn new_normal(number: u8) -> Option<Self>
pub fn new_normal(number: u8) -> Option<Self>
Construct a “normal” month code given a number (“Mxx”).
Returns an error for months greater than 99