ValidMonthCode

Struct ValidMonthCode 

pub(crate) struct ValidMonthCode {
    number: u8,
    is_leap: bool,
}
A MonthCode that has been parsed into its internal representation.

Fields

number: u8

Month number between 0 and 99

is_leap: bool

Implementations

Source

impl ValidMonthCode

pub(crate) fn try_from_utf8(bytes: &[u8]) -> Result<Self, MonthCodeParseError>

pub(crate) const fn new_unchecked(number: u8, is_leap: bool) -> Self

Create a new ValidMonthCode without checking that the number is between 1 and 99

pub fn number(self) -> u8

Returns the month number according to the month code.

This is NOT the same as the ordinal month!

Examples
use icu::calendar::Date;
use icu::calendar::cal::Hebrew;

let hebrew_date = Date::try_new_iso(2024, 7, 1).unwrap().to_calendar(Hebrew);
let month_info = hebrew_date.month();

// Hebrew year 5784 was a leap year, so the ordinal month and month number diverge.
assert_eq!(month_info.ordinal, 10);
assert_eq!(month_info.valid_month_code.number(), 9);
pub fn is_leap(self) -> bool

Returns whether the month is a leap month.

This is true for intercalary months in Hebrew and LunarChinese.

pub(crate) fn to_tuple(self) -> (u8, bool)

pub(crate) fn to_month_code(self) -> MonthCode